@@ -1,5 +1,5 @@
 from . import torch_util
 from . import scalars
-from . import io
+from . import i_o
 from . import one_dim_data_generators
 from . import preprocessing
